==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-appearance/lxqt-config-appearance_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../../../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="118"/>
        <location filename="../../../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuración de apariencia de LXQt</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Tema de iconos</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../../../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>Tema de LXQt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="44"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuración de apariencia de LXQt</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="50"/>
        <source>Widget Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="54"/>
        <source>Icons Theme</source>
        <translation>Tema de iconos</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="58"/>
        <source>LXQt Theme</source>
        <translation>Tema de LXQt</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="62"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="67"/>
        <source>Cursor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../../../styleconfig.ui" line="23"/>
        <source>Widget Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="54"/>
        <source>Toolbar button style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="62"/>
        <source>Only display the icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="67"/>
        <source>Only display the text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="72"/>
        <source>The text appears beside the icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="77"/>
        <source>The text appears under the icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="82"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="90"/>
        <source>Activate item on single click</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-config/lxqt-config-appearance/lxqt-config-appearance_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../../../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Fuente por omisión para la interfaz de usuario</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Nombre de la fuente:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Estilo:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Tamaño en puntos:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Negrita</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Cursiva</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Negrita cursiva</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Los ajustes siguientes solo afectan a las nuevas aplicaciones iniciadas</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Usar suavizado de fuentes</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Estilo de &quot;hinting&quot; de la fuente:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="118"/>
        <location filename="../../../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Ligero</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Completo</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>&quot;Hinting&quot; de la fuente</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Resolución (PPP):</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>&quot;Hint&quot; automático</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Representación de subpíxel:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuración de apariencia de LXQt</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Tema de iconos</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>La extensión de KDE para temas de icono XDG -&gt; FollowsColorScheme</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Colorear los iconos según el estilo de los controles (paleta)</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../../../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>Tema de LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtthemeconfig.ui" line="57"/>
        <source>Override user-defined wallpaper</source>
        <translation>Ignorar el fondo de pantalla definido por el usuario</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="57"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuración de apariencia de LXQt</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="63"/>
        <source>Widget Style</source>
        <translation>Estilo de los controles</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="67"/>
        <source>Icons Theme</source>
        <translation>Tema de iconos</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="71"/>
        <source>LXQt Theme</source>
        <translation>Tema de LXQt</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="75"/>
        <source>Font</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="80"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../../../styleconfig.ui" line="23"/>
        <source>Widget Style</source>
        <translation>Estilo de los controles</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="54"/>
        <source>Toolbar button style:</source>
        <translation>Estilo del botón de la barra de herramientas:</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="62"/>
        <source>Only display the icon</source>
        <translation>Mostrar solo el icono</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="67"/>
        <source>Only display the text</source>
        <translation>Mostrar solo el texto</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="72"/>
        <source>The text appears beside the icon</source>
        <translation>El texto aparece junto al icono</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="77"/>
        <source>The text appears under the icon</source>
        <translation>El texto aparece bajo el icono</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="82"/>
        <source>Default</source>
        <translation>Por omisión</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="90"/>
        <source>Activate item on single click</source>
        <translation>Activar elementos con un solo clic</translation>
    </message>
</context>
</TS>
